@@ -10,7 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2021 by mworion
+# written in python3, (c) 2019-2022 by mworion
 #
 # Licence APL2.0
 #
@@ -26,9 +26,10 @@ import astropy.io.fits as fits
 from base.tpool import Worker
 from base.indiClass import IndiClass
 from base.transform import JNowToJ2000
+from logic.camera.cameraSupport import CameraSupport
 
 
-class CameraIndi(IndiClass):
+class CameraIndi(IndiClass, CameraSupport):
     """
     """
 
@@ -77,8 +78,6 @@ class CameraIndi(IndiClass):
                                 )
 
         update = self.device.getNumber('POLLING_PERIOD')
-        if 'PERIOD_MS' not in update:
-            return False
         if update.get('PERIOD_MS', 0) == self.UPDATE_RATE:
             return True
 
@@ -95,10 +94,10 @@ class CameraIndi(IndiClass):
         as it is not explicit defined in the INDI spec. So downloaded is reached
         when that INDI state for CCD_EXPOSURE goes to IDLE or OK -> Jasem  Mutlaq.
         Another definition is done by myself, when INDI state for CCD_EXPOSURE is
-        BUSY and the CCD_EPOSURE_VALUE is not 0, then we should be on integration
-        side, else the download shoulds be started. The whole stuff is made,
+        BUSY and the CCD_EXPOSURE_VALUE is not 0, then we should be on integration
+        side, else the download should be started. The whole stuff is made,
         because on ALPACA and ASCOM side it's a step by step sequence, which has
-        very defined states for each step and I would like ta have a common
+        very defined states for each step. I would like ta have a common
         approach for all frameworks.
 
         :return: success
@@ -131,10 +130,22 @@ class CameraIndi(IndiClass):
         :param propertyName:
         :return:
         """
+        if propertyName == 'CCD_GAIN':
+            elements = self.device.CCD_GAIN['elementList']['GAIN']
+            self.data['CCD_GAIN.GAIN_MIN'] = elements.get('min', 0)
+            self.data['CCD_GAIN.GAIN_MAX'] = elements.get('max', 0)
+
+        if propertyName == 'CCD_OFFSET':
+            elements = self.device.CCD_OFFSET['elementList']['OFFSET']
+            self.data['CCD_OFFSET.OFFSET_MIN'] = elements.get('min', 0)
+            self.data['CCD_OFFSET.OFFSET_MAX'] = elements.get('max', 0)
+
         if not super().updateNumber(deviceName, propertyName):
             return False
+
         if propertyName == 'CCD_EXPOSURE':
             self.setExposureState()
+
         if propertyName == 'CCD_TEMPERATURE':
             self.data['CAN_SET_CCD_TEMPERATURE'] = True
         return True
@@ -144,18 +155,25 @@ class CameraIndi(IndiClass):
         adding for avoid having no entry in header
         :return:
         """
-        if 'RA' in header and 'DEC' in header:
-            return header
-        ra = self.app.mount.obsSite.raJNow
-        dec = self.app.mount.obsSite.decJNow
-        timeJD = self.app.mount.obsSite.timeJD
-        if ra is None or dec is None or timeJD is None:
+        if self.raJ2000 is None or self.decJ2000 is None:
+            self.log.debug('No coordinate for updating the header available')
             return header
 
-        ra, dec = JNowToJ2000(ra, dec, timeJD)
-        self.log.info('Missing Ra/Dec in header adding from mount')
-        header['RA'] = ra._degrees
-        header['DEC'] = dec.degrees
+        if 'RA' in header and 'DEC' in header:
+            t = f'Found FitsRA:[{header["RA"]:4.3f}], '
+            t += f'TargetRA: [{self.raJ2000._degrees:4.3f}], '
+            t += f'FitsDEC: [{header["DEC"]:4.3f}], '
+            t += f'TargetDEC: [{self.decJ2000._degrees:4.3f}]'
+            self.log.debug(t)
+            return header
+
+        t = 'Adding missing RA/DEC header '
+        t += f'TargetRA: [{self.raJ2000._degrees:4.3f}], '
+        t += f'TargetDEC: [{self.decJ2000._degrees:4.3f}]'
+        self.log.debug(t)
+
+        header['RA'] = self.raJ2000._degrees
+        header['DEC'] = self.decJ2000.degrees
         return header
 
     def workerSaveBlobSignalsFinished(self):
@@ -190,7 +208,7 @@ class CameraIndi(IndiClass):
 
         HDU[0].header = self.updateHeaderInfo(HDU[0].header)
         fits.writeto(self.imagePath, HDU[0].data, HDU[0].header,
-                     overwrite=True, output_verify='silentfix+warn')
+                     overwrite=True, output_verify='silentfix')
         return True
 
     def updateBLOB(self, deviceName, propertyName):
@@ -252,6 +270,8 @@ class CameraIndi(IndiClass):
                width=1,
                height=1,
                focalLength=1,
+               ra=None,
+               dec=None,
                ):
         """
         :param imagePath:
@@ -263,12 +283,17 @@ class CameraIndi(IndiClass):
         :param width:
         :param height:
         :param focalLength:
+        :param ra:
+        :param dec:
+
         :return: success
         """
         if not self.device:
             self.log.error('Expose, but no device present')
             return False
 
+        self.raJ2000 = ra
+        self.decJ2000 = dec
         self.imagePath = imagePath
         suc = self.sendDownloadMode(fastReadout=fastReadout)
         if not suc:
@@ -311,6 +336,8 @@ class CameraIndi(IndiClass):
         if not self.device:
             return False
 
+        self.raJ2000 = None
+        self.decJ2000 = None
         indiCmd = self.device.getSwitch('CCD_ABORT_EXPOSURE')
         if 'ABORT' not in indiCmd:
             return False
